@@ -1,9 +1,10 @@
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
 
-from incuna.db.models import Orderable
+from orderable.models import Orderable
 from profiles.models import Profile
 
+
 class ProfileFieldsChoices(object):
     """
     Iterable that will yield Profile fields as choices. 
